@@ -25,7 +25,7 @@ class DID:
     def __init__(self, did: str):
         """Validate and parse raw DID str."""
         self._raw = did
-        matched = DID_PATTERN.fullmatch(did)
+        matched = DID_PATTERN.match(did)
         if not matched:
             raise InvalidDIDError("Unable to parse DID {}".format(did))
         self._method = matched.group(1)
@@ -73,7 +73,7 @@ class DID:
     @classmethod
     def is_valid(cls, did: str):
         """Return if the passed string is a valid DID."""
-        return DID_PATTERN.fullmatch(did)
+        return DID_PATTERN.match(did)
 
     @classmethod
     def validate(cls, did: str):
